bearing.distance: Bearing and Distance

View source: R/bearing.distance.R

bearing.distanceR Documentation

Bearing and Distance

Description

Calculates a new point [X,Y] based on defined bearing and distance

Usage

bearing.distance(x, y, distance, azimuth, EastOfNorth = TRUE)

Arguments

x

x coordinate

y

y coordinate

distance

Distance to new point (in same units as x,y)

azimuth

Azimuth to new point

EastOfNorth

Specified surveying convention

Details

East of north is a surveying convention and defaults to true.

Value

a new point representing location of baring and distance

Author(s)

Jeffrey S. Evans <sage_insights@outlook.com>

Examples

 pt <- cbind( x=480933, y=4479433)
 bearing.distance(pt[1], pt[2], 1000, 40)


spatialEco documentation built on May 20, 2026, 9:09 a.m.